@@ -6,7 +6,7 @@ import redis
 
 
 class Publisher(object):
-    _instance_lock = threading.Lock()
+    # _instance_lock = threading.Lock()
 
     def __init__(self,
                  name='robot_reids_pub',
@@ -20,12 +20,12 @@ class Publisher(object):
         logging.debug('create a redis pool at {}:{} for publisher {}'.format(
             host, port, name))
 
-    def __new__(cls, *args, **kwargs):
-        if not hasattr(Publisher, '_instance'):
-            with Publisher._instance_lock:
-                if not hasattr(Publisher, '_instance'):
-                    Publisher._instance = object.__new__(cls)
-        return Publisher._instance
+    # def __new__(cls, *args, **kwargs):
+    #     if not hasattr(Publisher, '_instance'):
+    #         with Publisher._instance_lock:
+    #             if not hasattr(Publisher, '_instance'):
+    #                 Publisher._instance = object.__new__(cls)
+    #     return Publisher._instance
 
     def get_connection(self):
         return redis.StrictRedis(connection_pool=self.pool,
@@ -35,9 +35,10 @@ class Publisher(object):
                                  socket_timeout=4)
 
     def send(self, topic, dpack):
-        rc = Publisher._instance.get_connection()
-        name = Publisher._instance.name
-        rc.publish(topic, dpack)
-
-        logging.debug('Redis server {}\'s top {} publish a data at {}.'.format(
+        # rc = Publisher._instance.get_connection()
+        # name = Publisher._instance.name
+        rc = self.get_connection()
+        name = self.name
+        rc.publish(topic, dpack)        
+        logging.debug('Redis server {}\'s topic {} publish a data at {}.'.format(
             name, topic, time.time()))
